==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridToolbarHidingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarHidingDescription } from "./WebGridToolbarHidingDescription";
/**
 * @hidden
 */
export let WebGridToolbarHidingDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarHidingDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarHidingDescriptionMetadata.a == null) {
                WebGridToolbarHidingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarHidingDescriptionMetadata.c(WebGridToolbarHidingDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarHidingDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridToolbarHidingDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarHiding");
            a.item("__tagNameWC", "String:igc-grid-toolbar-hiding");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("__manageItemInMarkup", "Boolean");
        }
        static d(a) {
            WebGridToolbarHidingDescriptionMetadata.b(a);
            a.ad("WebGridToolbarHiding", () => new WebGridToolbarHidingDescription());
            a.ac("WebGridToolbarHiding", WebGridToolbarHidingDescriptionMetadata.a);
        }
    }
    WebGridToolbarHidingDescriptionMetadata.$t = markType(WebGridToolbarHidingDescriptionMetadata, 'WebGridToolbarHidingDescriptionMetadata');
    WebGridToolbarHidingDescriptionMetadata.a = null;
    return WebGridToolbarHidingDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridToolbarHidingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarHidingDescription } from "./WebGridToolbarHidingDescription";
/**
 * @hidden
 */
export let WebGridToolbarHidingDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarHidingDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarHidingDescriptionMetadata.a == null) {
                WebGridToolbarHidingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarHidingDescriptionMetadata.c(WebGridToolbarHidingDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarHidingDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridToolbarHidingDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarHiding");
            a.item("__tagNameWC", "String:igc-grid-toolbar-hiding");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("__manageItemInMarkup", "Boolean");
        }
        static d(a) {
            WebGridToolbarHidingDescriptionMetadata.b(a);
            a.ae("WebGridToolbarHiding", () => new WebGridToolbarHidingDescription());
            a.ad("WebGridToolbarHiding", WebGridToolbarHidingDescriptionMetadata.a);
        }
    }
    WebGridToolbarHidingDescriptionMetadata.$t = markType(WebGridToolbarHidingDescriptionMetadata, 'WebGridToolbarHidingDescriptionMetadata');
    WebGridToolbarHidingDescriptionMetadata.a = null;
    return WebGridToolbarHidingDescriptionMetadata;
})();
